==> bokehmol-0.1.0a3.tar.gz: bokehmol-0.1.0a3/README.md <==
# bokehmol, gotta plot them mol! ⌬

[![Powered by RDKit.js](https://img.shields.io/badge/Powered%20by-RDKit.js-3838ff.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQBAMAAADt3eJSAAAABGdBTUEAALGPC/xhBQAAACBjSFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAFVBMVEXc3NwUFP8UPP9kZP+MjP+0tP////9ZXZotAAAAAXRSTlMAQObYZgAAAAFiS0dEBmFmuH0AAAAHdElNRQfmAwsPGi+MyC9RAAAAQElEQVQI12NgQABGQUEBMENISUkRLKBsbGwEEhIyBgJFsICLC0iIUdnExcUZwnANQWfApKCK4doRBsKtQFgKAQC5Ww1JEHSEkAAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAyMi0wMy0xMVQxNToyNjo0NyswMDowMDzr2J4AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMjItMDMtMTFUMTU6MjY6NDcrMDA6MDBNtmAiAAAAAElFTkSuQmCC)](https://www.rdkit.org/)

**bokehmol** provides custom extensions that help plotting molecules with the
[Bokeh](https://docs.bokeh.org/) library.

It currently provides hover tools that can depict molecules **on-the-fly** using SMILES: no need to
pre-generate the depictions and store them in memory anymore! Everything is rendered client-side in
the browser so you don't even need to install rdkit in your Python environment.

## [Installation](https://pypi.org/project/bokehmol/)

Bokehmol only requires bokeh as a dependency. You can install it with:
```
pip install bokehmol
```

## [Notebooks](https://github.com/cbouy/bokehmol/tree/master/notebooks)

Some examples on how to use the library [![nbviewer](https://raw.githubusercontent.com/jupyter/design/master/logos/Badges/nbviewer_badge.svg)](https://nbviewer.org/github/cbouy/bokehmol/blob/master/notebooks/quickstart.ipynb)

## [Discussions](https://github.com/cbouy/bokehmol/discussions)

Feature requests or questions on how to use should be posted [here](https://github.com/cbouy/bokehmol/discussions)

## [Issues](https://github.com/cbouy/bokehmol/issues)

Bug [tracker](https://github.com/cbouy/bokehmol/issues) 🐞

==> bokehmol-0.1.1.tar.gz: bokehmol-0.1.1/README.md <==
# bokehmol, gotta plot them mol! ⌬

[![Powered by RDKit.js](https://img.shields.io/badge/Powered%20by-RDKit.js-3838ff.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQBAMAAADt3eJSAAAABGdBTUEAALGPC/xhBQAAACBjSFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAFVBMVEXc3NwUFP8UPP9kZP+MjP+0tP////9ZXZotAAAAAXRSTlMAQObYZgAAAAFiS0dEBmFmuH0AAAAHdElNRQfmAwsPGi+MyC9RAAAAQElEQVQI12NgQABGQUEBMENISUkRLKBsbGwEEhIyBgJFsICLC0iIUdnExcUZwnANQWfApKCK4doRBsKtQFgKAQC5Ww1JEHSEkAAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAyMi0wMy0xMVQxNToyNjo0NyswMDowMDzr2J4AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMjItMDMtMTFUMTU6MjY6NDcrMDA6MDBNtmAiAAAAAElFTkSuQmCC)](https://www.rdkit.org/)

**bokehmol** provides custom extensions that help plotting molecules with the
[Bokeh](https://docs.bokeh.org/) library.

It currently provides hover tools that can depict molecules **on-the-fly** using SMILES: no need to
pre-generate the depictions and store them in memory anymore! Everything is rendered client-side in
the browser so you don't even need to install rdkit in your Python environment.

<img width="600" alt="image" src="https://github.com/cbouy/bokehmol/assets/27850535/e33c4185-301a-477a-9a6b-fea2939ad540">


## [Installation](https://pypi.org/project/bokehmol/)

Bokehmol only requires bokeh as a dependency. You can install it with:
```
pip install bokehmol
```

## [Notebooks](https://github.com/cbouy/bokehmol/tree/master/notebooks)

Some examples on how to use the library [here](https://rawcdn.githack.com/cbouy/bokehmol/9ee061268dee125268489041586dac5e757fa6a3/notebooks/quickstart.html)

## [Discussions](https://github.com/cbouy/bokehmol/discussions)

Feature requests or questions on how to use should be posted [here](https://github.com/cbouy/bokehmol/discussions)

## [Issues](https://github.com/cbouy/bokehmol/issues)

Bug [tracker](https://github.com/cbouy/bokehmol/issues) 🐞
